@@ -23,13 +23,13 @@
 #ifndef LIBCOUCHBASE_COUCHBASE_H
 #define LIBCOUCHBASE_COUCHBASE_H 1
 
-#include <stdint.h>
 #include <stddef.h>
 #include <time.h>
 
 #include <libcouchbase/configuration.h>
 #include <libcouchbase/visibility.h>
 #include <libcouchbase/types.h>
+#include <libcouchbase/compat.h>
 #include <libcouchbase/behavior.h>
 #include <libcouchbase/callbacks.h>
 #include <libcouchbase/tap_filter.h>
@@ -61,15 +61,19 @@ extern "C" {
      * @return pointer to a newly created io ops structure
      */
     LIBCOUCHBASE_API
-    libcouchbase_io_opt_t* libcouchbase_create_io_ops(libcouchbase_io_ops_type_t type,
+    libcouchbase_io_opt_t *libcouchbase_create_io_ops(libcouchbase_io_ops_type_t type,
                                                       void *cookie,
                                                       libcouchbase_error_t *error);
 
 
     /**
-     * Create an instance of libcouchbase
-     * @param host The host (with optional port) to connect to retrieve the
-     *             vbucket list from
+     * Create an instance of libcouchbase.
+     *
+     * @param hosts A list of hosts:port separated by ';' to the
+     *              administration port of the couchbase cluster. (ex:
+     *              "host1;host2:9000;host3" would try to connect to
+     *              host1 on port 8091, if that fails it'll connect to
+     *              host2 on port 9000 etc).
      * @param user the username to use
      * @param passwd The password
      * @param bucket The bucket to connect to
@@ -150,7 +154,7 @@ extern "C" {
      * @param instance the handle to libcouchbase
      */
     LIBCOUCHBASE_API
-    void libcouchbase_flush_buffers(libcouchbase_t instance, const void* cookie);
+    void libcouchbase_flush_buffers(libcouchbase_t instance, const void *cookie);
 
     /**
      * Associate a cookie with an instance of libcouchbase
@@ -212,7 +216,7 @@ extern "C" {
     libcouchbase_error_t libcouchbase_mget(libcouchbase_t instance,
                                            const void *command_cookie,
                                            libcouchbase_size_t num_keys,
-                                           const void * const *keys,
+                                           const void *const *keys,
                                            const libcouchbase_size_t *nkey,
                                            const libcouchbase_time_t *exp);
 
@@ -240,7 +244,7 @@ extern "C" {
                                                   const void *hashkey,
                                                   libcouchbase_size_t nhashkey,
                                                   libcouchbase_size_t num_keys,
-                                                  const void * const *keys,
+                                                  const void *const *keys,
                                                   const libcouchbase_size_t *nkey,
                                                   const libcouchbase_time_t *exp);
 
@@ -265,7 +269,7 @@ extern "C" {
     libcouchbase_error_t libcouchbase_mtouch(libcouchbase_t instance,
                                              const void *command_cookie,
                                              libcouchbase_size_t num_keys,
-                                             const void * const *keys,
+                                             const void *const *keys,
                                              const libcouchbase_size_t *nkey,
                                              const libcouchbase_time_t *exp);
 
@@ -294,7 +298,7 @@ extern "C" {
                                                     const void *hashkey,
                                                     libcouchbase_size_t nhashkey,
                                                     libcouchbase_size_t num_keys,
-                                                    const void * const *keys,
+                                                    const void *const *keys,
                                                     const libcouchbase_size_t *nkey,
                                                     const libcouchbase_time_t *exp);
 
@@ -321,10 +325,24 @@ extern "C" {
      */
     LIBCOUCHBASE_API
     libcouchbase_error_t libcouchbase_server_stats(libcouchbase_t instance,
-                                                   const void* command_cookie,
-                                                   const void* arg,
+                                                   const void *command_cookie,
+                                                   const void *arg,
                                                    libcouchbase_size_t narg);
 
+    /**
+     * Request server versions. The callback will be invoked with the
+     * instance, server address, version string, and version string length.
+     *
+     * When all server versions have been received, the callback is invoked
+     * with the server endpoint argument set to NULL
+     *
+     * @param instance the handle to libcouchbase
+     * @param command_cookie a cookie passed to each invocation of the callback
+     *                          from this command
+     */
+    LIBCOUCHBASE_API
+    libcouchbase_error_t libcouchbase_server_versions(libcouchbase_t instance,
+                                                      const void *command_cookie);
     /**
      * Spool a store operation to the cluster. The operation <b>may</b> be
      * sent immediately, but you won't be sure (or get the result) until you
@@ -523,7 +541,7 @@ extern "C" {
      */
     LIBCOUCHBASE_API
     libcouchbase_error_t libcouchbase_flush(libcouchbase_t instance,
-                                            const void* cookie);
+                                            const void *cookie);
 
 #ifdef __cplusplus
 }
